/**
 * Copyright 2010-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.substitution.engine.element;

import org.ow2.util.substitution.IPropertyResolver;
import org.ow2.util.substitution.engine.IResolvableElement;
import org.ow2.util.substitution.engine.util.StringUtils;

/**
 * a FixedValueElement is a resolvable element that will always return the same value.
 * @author Guillaume Sauthier
 */
public class FixedValueElement implements IResolvableElement {

    /**
     * Fixed value.
     */
    private String value;

    public FixedValueElement(final String value) {
        this.value = value;
    }

    /**
     * Simply return the initially provided value
     * @param resolver not used
     * @return a String representation of this resolved element
     */
    public String getValue(final IPropertyResolver resolver) {
        return value;
    }

    @Override
    public String toString() {
        return toString(0);
    }


    /**
     * Produces an indented String representation of this element.
     * @param indent indentation value
     * @return a String representation
     */
    public String toString(final int indent) {
        StringBuilder sb = new StringBuilder();
        sb.append(StringUtils.increment(indent));
        sb.append('\'');
        sb.append(value);
        sb.append("\'");
        return sb.toString();
    }

}
