/**
 * Copyright 2010-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.substitution.engine.element;

import org.ow2.util.substitution.IPropertyResolver;
import org.ow2.util.substitution.engine.IResolvableElement;
import org.ow2.util.substitution.engine.util.StringUtils;

/**
 * A VariableElement is a CompositeElement that knows how to handle multiple level resolution.
 * Example:
 * <code>
 *  ${composite.${value}}
 * </code>
 * @author Guillaume Sauthier
 */
public class VariableElement extends CompositeElement {

    /**
     * Resolve the value result of the composite resolution.
     * @param resolver IPropertyResolver to be used
     * @return a String representation of this resolved element
     */
    @Override
    public String getValue(IPropertyResolver resolver) {
        // Get the composite resolved value
        String name =  super.getValue(resolver);
        // Resolve again
        return resolver.resolve(name);
    }

    /**
     * Produces an indented String representation of this element.
     * @param indent indentation value
     * @return a String representation
     */
    @Override
    public String toString(int indent) {
        StringBuilder sb = new StringBuilder();
        sb.append(StringUtils.increment(indent));


        if (getElements().size() == 1) {
            sb.append("${");
            sb.append(getElements().get(0).toString());
            sb.append("}");
        } else {

            sb.append("${");
            sb.append('\n');
            for (IResolvableElement element : getElements()) {
                sb.append(element.toString(indent + 1));
                sb.append('\n');
            }
            sb.append(StringUtils.increment(indent));
            sb.append("}");

        }

        return sb.toString();
    }
}
