/**
 * Copyright 2010-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.substitution.engine.util;

/**
 * Utility class for String processing.
 * @author Guillaume Sauthier
 */
public class StringUtils {

    /**
     * The empty String.
     */
    private final static String EMPTY_STRING = "";

    /**
     * Produces an increment String sized given the provided indent value
     * @param indent expected indentation
     * @return increment String
     */
    public static String increment(final int indent) {
        return increment(indent, "  ");
    }

    /**
     * Produces an increment String sized given the provided indent value
     * @param indent expected indentation
     * @param block block of increment to be replicated
     * @return increment String
     */
    public static String increment(final int indent, final String block) {
        StringBuilder sb = new StringBuilder();
        for (int i = 0; i < indent; i++) {
            sb.append(block);
        }
        return sb.toString();
    }

    /**
     * Returns {@code true} if value is null or empty.
     * @param value tested String
     * @return true/false
     */
    public static boolean isEmpty(final String value) {
        return (value == null) || (EMPTY_STRING.equals(value));
    }
}
