/**
 * Copyright 2010-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.substitution.resolver;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.substitution.IPropertyResolver;

/**
 * Manage a List of IPropertyResolver. During resolution, the first non-null value returned by a resolver is used.
 * Order is the one of the resolvers List.
 * @author Guillaume Sauthier
 */
public class ChainedResolver implements IPropertyResolver {

    /**
     * Chain of resolvers.
     */
    private List<IPropertyResolver> resolvers;

    public ChainedResolver() {
        this.resolvers = new ArrayList<IPropertyResolver>();
    }

    public List<IPropertyResolver> getResolvers() {
        return resolvers;
    }

    /**
     * @param expression a property name
     * @return the value related to the expression, or null if not found.
     */
    public String resolve(final String expression) {

        // Return the first resolved value
        for (IPropertyResolver resolver : resolvers) {
            String resolved = resolver.resolve(expression);
            if (resolved != null) {
                return resolved;
            }
        }
        return null;
    }
}
