/**
 * Copyright 2010-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.substitution.resolver;

import org.ow2.util.substitution.IPropertyResolver;


/**
 * A FallbackResolver is a resolver, usually placed at the end of a chain of resolver
 * and that will provide a default value for any given expression.
 * This permits to have a little less strict resolution process (the substitution engine
 * throwing exceptions if the resolver cannot give a non-null value)
 * @author Guillaume Sauthier
 */
public class FallbackResolver implements IPropertyResolver {

    /**
     * @param expression a property name
     * @return the value related to the expression, or null if not found.
     */
    public String resolve(String expression) {
        // Always return something
        return "[" + expression + ":unresolved]";
    }
}
